@@ -557,7 +557,7 @@ List* db_get_last_elements_4_list(int ticket_id, List* elements)
     sprintf(sql, "select t.id, org_m.field%d ", ELEM_ID_SENDER);
     strcat(sql, columns);
     sprintf(sql_suf, 
-            "  , t.registerdate, last_m.registerdate,  "
+            "  , substr(t.registerdate, 0, 16), substr(last_m.registerdate, 0, 16),  "
             "  julianday(current_date) - julianday(date(last_m.registerdate)) as passed_date "
             "from ticket as t "
             "inner join message as last_m on last_m.id = t.last_message_id "
@@ -1175,4 +1175,4 @@ Wiki* db_get_newest_wiki(char* page_name, Wiki* wiki)
 
 ERROR_LABEL
 }
-/* vim: set ts=4 sw=4 sts=4 expandtab: */
+/* vim: set ts=4 sw=4 sts=4 expandtab fenc=utf-8: */
