@@ -10,6 +10,23 @@
 #include "wiki.h"
 #include "hook.h"
 
+typedef enum _NAVI {
+    NAVI_OTHER,
+    NAVI_TOP,
+    NAVI_LIST,
+    NAVI_REGISTER,
+    NAVI_SEARCH,
+    NAVI_RSS,
+    NAVI_HELP,
+    NAVI_STATISTICS,
+    NAVI_MANAGEMENT
+} NaviType;
+typedef enum _MODE {
+    MODE_INVALID,
+    MODE_REGISTER,
+    MODE_REPLY
+} ModeType;
+
 /* prototype declares */
 void register_actions();
 void list_action();
@@ -25,23 +42,17 @@ void download_action();
 void report_csv_download_action();
 void rss_action();
 void top_action();
-void output_header(Project*, char*, char*, int);
+void output_header(Project*, char*, char*, NaviType);
 void output_footer();
 int cgiMain();
 void output_form_element(List*, ElementType*);
 void output_form_element_4_condition(ElementType*);
-int get_mode();
+ModeType get_mode();
 static int contains(char* const, const char*);
 void output_calendar_js();
 
 #define COOKIE_SENDER "starbug1_sender"
-enum MODE {
-    MODE_INVALID,
-    MODE_REGISTER,
-    MODE_REPLY
-};
-
-int get_mode()
+ModeType get_mode()
 {
     char mode[MODE_LENGTH];
     cgiFormStringNoNewlines("register", mode, MODE_LENGTH);
@@ -68,18 +79,7 @@ void register_actions()
     register_action_actions("top", top_action);
 }
 
-enum NAVI {
-    NAVI_OTHER,
-    NAVI_TOP,
-    NAVI_LIST,
-    NAVI_REGISTER,
-    NAVI_SEARCH,
-    NAVI_RSS,
-    NAVI_HELP,
-    NAVI_STATISTICS,
-    NAVI_MANAGEMENT
-};
-void output_header(Project* project, char* title, char* script_name, int navi)
+void output_header(Project* project, char* title, char* script_name, NaviType navi)
 {
     o("Pragma: no-cache\r\n");
     o("Cache-Control: no-cache\t\n");
@@ -264,7 +264,7 @@ void output_ticket_table_body(SearchResult* result, List* element_types)
         list_alloc(elements_a, Element);
         elements_a = db_get_last_elements_4_list(message->id, elements_a);
         o("\t<tr>\n"
-          "\t\t<td class=\"field%d-\"><a href=\"%s/ticket/%s\">%s</a></td>\n", 
+          "\t\t<td class=\"id field%d-\"><a href=\"%s/ticket/%s\">%s</a></td>\n", 
                 ELEM_ID_ID, 
                 cgiScriptName, 
                 get_element_value_by_id(elements_a, ELEM_ID_ID), 
@@ -272,7 +272,7 @@ void output_ticket_table_body(SearchResult* result, List* element_types)
         foreach (it, element_types) {
             ElementType* et = it->element;
             char* val = get_element_value_by_id(elements_a, et->id);
-            o("\t\t<td class=\"field%d-", et->id); 
+            o("\t\t<td class=\"field%d field%d-", et->id, et->id); 
             if (et->type == ELEM_TYPE_LIST_SINGLE)
                 css_field(val);
             o("\">");
@@ -286,9 +286,9 @@ void output_ticket_table_body(SearchResult* result, List* element_types)
                 o("</a>");
             o("&nbsp;</td>\n");
         }
-        o("\t\t<td>"); h(get_element_value_by_id(elements_a, ELEM_ID_REGISTERDATE)); o("&nbsp;</td>\n");
-        o("\t\t<td>"); h(get_element_value_by_id(elements_a, ELEM_ID_LASTREGISTERDATE)); o("&nbsp;</td>\n");
-        o("\t\t<td>"); h(get_element_value_by_id(elements_a, ELEM_ID_LASTREGISTERDATE_PASSED)); o("&nbsp;</td>\n");
+        o("\t\t<td class=\"registerdate\">"); h(get_element_value_by_id(elements_a, ELEM_ID_REGISTERDATE)); o("&nbsp;</td>\n");
+        o("\t\t<td class=\"lastregisterdate\">"); h(get_element_value_by_id(elements_a, ELEM_ID_LASTREGISTERDATE)); o("&nbsp;</td>\n");
+        o("\t\t<td class=\"passed\">"); h(get_element_value_by_id(elements_a, ELEM_ID_LASTREGISTERDATE_PASSED)); o("&nbsp;</td>\n");
         o("\t</tr>\n");
     }
 }
@@ -750,7 +750,7 @@ void report_csv_download_action()
     states_a = db_get_states(states_a);
 
     o("Content-Disposition: attachment; filename=\"report.csv\"\r\n");
-    cgiHeaderContentType("text/plain; charset=Windows-31J;");
+    cgiHeaderContentType("text/x-csv; charset=Windows-31J;");
 
     csv_field(project_a->name); o("\r\n");
     xfree(project_a);
@@ -883,7 +883,7 @@ void output_form_element(List* elements, ElementType* et)
             v(et->name);
             o("\" %s />",
                     (strlen(value) || strcmp(value, "0") == 0) ? "checked=\"checked\"" : "");
-            o("<label for=\"field%d\">", et->id); h(et->name); o("</lable>\n");
+            o("<label for=\"field%d\">", et->id); h(et->name); o("</label>\n");
             break;
         case ELEM_TYPE_LIST_SINGLE:
             o("<select id=\"field%d\" name=\"field%d\">\n",
@@ -948,7 +948,7 @@ void output_form_element(List* elements, ElementType* et)
         case ELEM_TYPE_LIST_MULTI:
             if (et->auto_add_item) {
                 /* 新規項目を設定可能である場合、テキストボックスを表示する。 */
-                o("<input type=\"text\" class=\"element_new_item\" id=\"field%d\" name=\"field%d.new_item\" />\n",
+                o("<input type=\"text\" class=\"element_new_item\" id=\"field%d.new_item\" name=\"field%d.new_item\" />\n",
                     et->id, et->id);
                 o("選択肢を追加する場合はテキストボックスに入力してください。\n");
             }
@@ -1092,7 +1092,7 @@ void ticket_action()
     message_ids_a = db_get_message_ids_a(iid);
     list_alloc(element_types_a, ElementType);
     element_types_a = db_get_element_types_all(element_types_a);
-    o("<h2 id=\"subject\">"); h(project_a->name); o(" - ID:%5d ", iid);
+    o("<h2 id=\"subject\">"); h(project_a->name); o(" - #%d ", iid);
     xfree(project_a);
     h(get_element_value_by_id(elements_a, ELEM_ID_TITLE));
     o(" &nbsp;</h2>\n");
@@ -1146,12 +1146,12 @@ void ticket_action()
             if (et->type == ELEM_TYPE_UPLOADFILE) {
                 char* attachment_file_name = get_element_value(attachment_elements_a, et);
                 if (strlen(attachment_file_name) == 0) continue;
-                o("\t\t<div>\n");
+                o("\t\t<span>\n");
                 o("<a href=\"%s/download/%d/", 
                         cgiScriptName, 
                         db_get_element_file_id(message_ids_a[i], et->id)); 
                 u(attachment_file_name); o("\" target=\"_blank\">");h(attachment_file_name); o("</a>\n");
-                o("\t\t&nbsp;</div>\n");
+                o("\t\t&nbsp;</span>\n");
             }
         }
         list_free(attachment_elements_a);
@@ -1170,16 +1170,20 @@ void ticket_action()
         List* previous = last_elements;
         list_alloc(elements_a, Element);
         last_elements = elements_a = db_get_elements(message_ids_a[i], elements_a);
-
-        o(      "<table summary=\"reply table\">\n"
-                "\t<tr>\n"
-                "\t\t<td colspan=\"2\" class=\"title\">投稿: %d ", i + 1); o("["); h(get_element_value_by_id(elements_a, ELEM_ID_LASTREGISTERDATE)); o("]</td>\n"
-                "\t</tr>\n");
+        o(      "\t\t<h4 class=\"title\">%d: ", i + 1);
+        h(get_element_value_by_id(elements_a, ELEM_ID_SENDER));
+        o("&nbsp;<span class=\"date\">("); h(get_element_value_by_id(elements_a, ELEM_ID_LASTREGISTERDATE)); o(")</span>&nbsp;");
+        o(      "\t</h4>\n");
+        o(      "<table summary=\"reply table\">\n");
         foreach (it, element_types_a) {
             ElementType* et = it->element;
             char* value = get_element_value(elements_a, et);
             char* last_value = get_element_value(previous, et);
 
+            /* 
+             * 投稿者は表示しない。 */
+            if (et->id == ELEM_ID_SENDER)
+                continue;
             /* チケット属性で、直前の値と同じ項目は表示しない。 */
             if (et->ticket_property == 1 && strcmp(value, last_value) == 0)
                 continue;
@@ -1229,10 +1233,13 @@ void ticket_action()
             "<form id=\"reply_form\" name=\"reply_form\" action=\"%s/register_submit\" method=\"post\" enctype=\"multipart/form-data\">\n", cgiScriptName);
     o(      "<input type=\"hidden\" name=\"ticket_id\" value=\"%s\" />\n", ticket_id);
     o(      "<div class=\"description\">返信を行なう場合は、以下のフォームに内容を記入して返信ボタンを押してください。</div>\n"
-            "<noscript><div class=\"description\">※必須項目の入力チェックは、javascriptで行なっています。</div></noscript>\n"
+            "<noscript><div class=\"description\">※必須項目の入力チェックは、javascriptで行なっています。</div></noscript>\n");
+    o(      "<h4>チケット情報の更新</h4>\n"
+            "<div class=\"description\">チケット情報(チケットの状態など)を更新する必要がある場合は、以下の情報を変更してください。</div>\n"
             "<table summary=\"input table\">\n");
     foreach (it, element_types_a) {
         ElementType* et = it->element;
+        if (et->ticket_property == 0) continue;
         o("\t<tr>\n");
         o("\t\t<th %s>", et->required ? "class=\"required\"" : "");
         if (et->ticket_property)
@@ -1260,8 +1267,42 @@ void ticket_action()
         o("\t</td>\n");
         o("\t</tr>\n");
     }
-    o(      "</table>\n"
-            "<input class=\"button\" type=\"submit\" name=\"reply\" value=\"返信\" />&nbsp;&nbsp;&nbsp;\n"
+    o(      "</table>\n");
+    o(      "<h4>返信情報の追加</h4>\n"
+            "<div class=\"description\">返信情報を記入してください。</div>\n"
+            "<table summary=\"input table\">\n");
+    foreach (it, element_types_a) {
+        ElementType* et = it->element;
+        if (et->ticket_property == 1) continue;
+        o("\t<tr>\n");
+        o("\t\t<th %s>", et->required ? "class=\"required\"" : "");
+        if (et->ticket_property)
+            o("&nbsp;<span class=\"ticket_property\" title=\"チケット属性\">");
+        h(et->name);
+        if (et->required)
+            o("<span class=\"required\">※</span>");
+        if (et->ticket_property)
+            o("</span>");
+        o("</th>\n\t\t<td>");
+        if (et->required)
+            o("\t\t<div id=\"field%d.required\" class=\"error\"></div>\n", et->id);
+        if (et->type == ELEM_TYPE_DATE)
+            o("\t\t<div id=\"field%d.datefield\" class=\"error\"></div>\n", et->id);
+        if (last_elements != NULL) {
+            if (et->ticket_property)
+                output_form_element(last_elements, et);
+            else
+                output_form_element(NULL, et);
+/*                 last_elements = last_elements->next; */
+        } else {
+            output_form_element(NULL, et);
+        }
+        o("\t\t<div class=\"description\">");h(et->description);o("&nbsp;</div>\n");
+        o("\t</td>\n");
+        o("\t</tr>\n");
+    }
+    o(      "</table>\n");
+    o(      "<input class=\"button\" type=\"submit\" name=\"reply\" value=\"返信\" />&nbsp;&nbsp;&nbsp;\n"
             "<input id=\"save2cookie\" type=\"checkbox\" name=\"save2cookie\" class=\"checkbox\" value=\"1\" %s />\n"
             "<label for=\"save2cookie\">投稿者を保存する。(cookie使用)</label>\n"
             "</form>\n"
@@ -1293,7 +1334,7 @@ void register_submit_action()
     List* elements_a = NULL;
     Message* ticket_a;
     char ticket_id[DEFAULT_LENGTH];
-    int mode = get_mode();
+    ModeType mode = get_mode();
     char** multi;
     char save2cookie[2];
     char* complete_message = NULL;
@@ -1301,7 +1342,7 @@ void register_submit_action()
 
     cgiFormStringNoNewlines("save2cookie", save2cookie, 2);
     if (mode == MODE_INVALID)
-        die("reqired invalid mode.");
+        die("requested invalid mode.");
     ticket_a = xalloc(sizeof(Message));
     db_init();
     project_a = db_get_project(project_a);
@@ -1704,13 +1745,30 @@ void edit_top_action()
             "<h3>簡易wikiのサポートする文法</h3>\n"
             "<ul>\n"
             "<li>行頭に*を記述した行は、大見出しになります。</li>\n"
-           "<li>行頭に**を記述した行は、中見出しになります。</li>\n"
+            "<li>行頭に**を記述した行は、中見出しになります。</li>\n"
             "<li>行頭に***を記述した行は、小見出しになります。</li>\n"
             "<li>行頭に****を記述した行は、極小見出しになります。</li>\n"
             "<li>行頭に-を記述した行は、箇条書きになります。</li>\n"
             "<li>行頭に----を記述した行は、区切り線になります。</li>\n"
-            "<li>行頭が空白スペースから始まる行は、整形済みブロックになります。</li>\n"
+            "<li>行頭が >| から始まる行から、行頭が |< から始まる行までは、整形済みブロックになります。</li>\n"
             "</ul>\n"
+            "<h5>例</h5>\n"
+            "<pre>\n"
+            "*編集可能領域\n"
+            "自由に編集できます。\n"
+            "右側の「トップページの編集」のリンクから編集してください。\n"
+            "色々な用途に使用してください。\n"
+            "-お知らせ\n"
+            "-Starbug1の使い方についての注意事項など\n"
+            "\n"
+            ">|\n"
+            "void displayWidgets (Iterable<Widget> widgets) {\n"
+            "  for (Widget w : widgets) {\n"
+            "    w.display();\n"
+            "  }\n"
+            "}\n"
+            "|<\n"
+            "</pre>\n"
             "</div>\n"
             "</div>\n");
     db_finish();
@@ -1763,4 +1821,4 @@ error:
     cgiHeaderContentType("text/plain; charset=utf-8;");
     o("error: ファイルがありません。");
 }
-/* vim: set ts=4 sw=4 sts=4 expandtab: */
+/* vim: set ts=4 sw=4 sts=4 expandtab fenc=utf-8: */
